==> percona-server-mongodb_4.0.18.orig.tar.gz: percona-server-mongodb-4.0.18-11/src/mongo/db/query/query_test_service_context.h <==

/**
 *    Copyright (C) 2018-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/client.h"
#include "mongo/db/logical_session_id.h"
#include "mongo/db/service_context.h"

namespace mongo {

/**
 * QueryTestServiceContext is a helper class for tests that require only a single Client under a
 * single ServiceContext for their execution context. The owned ServiceContext is decorated with a
 * CollatorFactoryMock.
 */
class QueryTestServiceContext {
public:
    QueryTestServiceContext();
    ~QueryTestServiceContext();

    ServiceContext::UniqueOperationContext makeOperationContext();

    ServiceContext::UniqueOperationContext makeOperationContext(LogicalSessionId lsid);

    Client* getClient() const;
    ServiceContext* getServiceContext();

private:
    ServiceContext::UniqueServiceContext _service;
    ServiceContext::UniqueClient _client;
};

}  // namespace mongo

==> percona-server-mongodb-36_3.6.6.orig.tar.gz: percona-server-mongodb-3.6.6-1.4/src/mongo/db/query/query_test_service_context.h <==
/**
 *    Copyright (C) 2016 MongoDB Inc.
 *
 *    This program is free software: you can redistribute it and/or  modify
 *    it under the terms of the GNU Affero General Public License, version 3,
 *    as published by the Free Software Foundation.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU Affero General Public License for more details.
 *
 *    You should have received a copy of the GNU Affero General Public License
 *    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the GNU Affero General Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/db/client.h"
#include "mongo/db/logical_session_id.h"
#include "mongo/db/service_context_noop.h"

namespace mongo {

/**
 * QueryTestServiceContext is a helper class for tests that require only a single Client under a
 * single ServiceContext for their execution context. The owned ServiceContext is decorated with a
 * CollatorFactoryMock.
 */
class QueryTestServiceContext {
public:
    QueryTestServiceContext();

    ServiceContext::UniqueOperationContext makeOperationContext();

    ServiceContext::UniqueOperationContext makeOperationContext(LogicalSessionId lsid);

    Client* getClient() const;

    ServiceContext* getServiceContext() {
        return &_serviceContext;
    }

private:
    ServiceContextNoop _serviceContext;
    ServiceContext::UniqueClient _uniqueClient;
};

}  // namespace mongo
